@@ -1,8 +1,8 @@
-( cd sbin ; rm -rf rmt )
-( cd sbin ; ln -sf /usr/libexec/rmt rmt )
+( cd bin ; rm -rf tar-1.22 )
+( cd bin ; ln -sf tar tar-1.22 )
 ( cd etc ; rm -rf rmt )
 ( cd etc ; ln -sf /usr/libexec/rmt rmt )
 ( cd usr/bin ; rm -rf tar )
 ( cd usr/bin ; ln -sf /bin/tar tar )
-( cd bin ; rm -rf tar-1.16.1 )
-( cd bin ; ln -sf tar tar-1.16.1 )
+( cd sbin ; rm -rf rmt )
+( cd sbin ; ln -sf /usr/libexec/rmt rmt )
